#[non_exhaustive]pub struct NomadsSurface {
pub geopotential_height_m: f64,
pub height_msl_m: f64,
pub pressure_pa: f64,
pub temperature_k: f64,
pub relative_humidity: f64,
pub wind_east_m_s: f64,
pub wind_north_m_s: f64,
}Expand description
The ground under the forecast, at the site.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.geopotential_height_m: f64The model’s terrain height as the cut gives it, gpm.
height_msl_m: f64Its geometric height above mean sea level, m (WMO-No. 8 eq. 12.16).
pressure_pa: f64Surface pressure, Pa.
temperature_k: f64Temperature 2 m above the ground, K.
relative_humidity: f64Relative humidity 2 m above the ground, a fraction, as recorded (it may pass 1).
wind_east_m_s: f64The 10 m wind’s east component, m/s.
wind_north_m_s: f64The 10 m wind’s north component, m/s.