FindError

Enum FindError 

#[non_exhaustive]
pub enum FindError { NotFound { wanted: String, }, Ambiguous { wanted: String, matches: u32, candidates: Vec<String>, }, Hybrid { motor: String, }, NoFile { motor: String, why: Option<String>, }, ThrustCurve(ThrustCurveError), }
Why no motor was found.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotFound

No motor has the name as its designation or its common name.

Fields

wanted: String

The motor asked for, in words.



Ambiguous

Several solid motors answer the name.

Fields

wanted: String

The motor asked for, in words.

matches: u32

How many motors the search says match.

candidates: Vec<String>

Those the answer lists, each as maker designation.



Hybrid

The one motor that answers is a hybrid.

Fields

motor: String

The motor, as maker designation.



NoFile

The motor has no RASP or RockSim file that hpr_motor reads.

Fields

motor: String

The motor, as maker designation.

why: Option<String>

Why the last file tried was refused; None when there were none.



ThrustCurve(ThrustCurveError)

A request or answer was refused, or the fetch failed.

Implementations

Source

impl FindError

pub fn is_not_cached(&self) -> bool

Whether it failed only because, offline, an answer is not in the cache: a fetch with a network connection would answer.