#[non_exhaustive]pub enum DropReason {
BelowGround,
NoData,
Humidity,
}Expand description
Why a pressure level was left out of the profile.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BelowGround
Its pressure is not below the surface pressure, or its height is not above the ground.
NoData
A value is missing (null) at one of the two hours.
Humidity
Its relative humidity is outside 0 to 100%, which a sounding refuses.