#[non_exhaustive]pub struct OpenMeteoLevel {
pub pressure_pa: f64,
pub geopotential_height_m: f64,
pub height_msl_m: f64,
pub temperature_k: f64,
pub relative_humidity: f64,
pub wind_speed_m_s: f64,
pub wind_direction_from_rad: f64,
}Expand description
One pressure level above the ground, at the launch time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pressure_pa: f64The level’s pressure, Pa.
geopotential_height_m: f64Its geopotential height as the response gives it, gpm.
height_msl_m: f64Its geometric height above mean sea level, m (WMO-No. 8 eq. 12.16).
temperature_k: f64Temperature, K.
relative_humidity: f64Relative humidity, a fraction.
wind_speed_m_s: f64Wind speed, m/s.
wind_direction_from_rad: f64Direction the wind blows from, clockwise from true north, rad in [0, 2π).