#[non_exhaustive]pub struct OpenMeteoSurface {
pub height_msl_m: f64,
pub pressure_pa: f64,
pub temperature_k: f64,
pub relative_humidity: f64,
pub wind_speed_m_s: f64,
pub wind_direction_from_rad: f64,
}Expand description
The ground under the forecast, at the launch time.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.height_msl_m: f64The response’s elevation: the ground’s height above mean sea level, m.
pressure_pa: f64Surface pressure, Pa.
temperature_k: f64Temperature 2 m above the ground, K.
relative_humidity: f64Relative humidity 2 m above the ground, a fraction.
wind_speed_m_s: f64Wind speed 10 m above the ground, m/s.
wind_direction_from_rad: f64Direction the 10 m wind blows from, clockwise from true north, rad in [0, 2π).