fetch_download

Function fetch_download 

pub fn fetch_download<T: Transport>(
    client: &Client<T>,
    download: &Download,
    now_s: u64,
) -> Result<(DownloadAnswer, Fetched), ThrustCurveError>
Fetches a motor’s data files through client, as fetch_search does. An answer holding another motor’s file, or a file in another format, is refused and never cached.

Errors

As fetch_search; with NetError::Refused naming ThrustCurveError::OtherMotor for a file of another motor or format than asked.