#[non_exhaustive]pub struct WyomingLevel {
pub pressure_pa: f64,
pub geopotential_height_m: f64,
pub height_msl_m: f64,
pub temperature_k: f64,
pub relative_humidity: f64,
pub wind_speed_m_s: f64,
pub wind_direction_from_rad: f64,
}Expand description
One level of a sounding, as recorded, in SI units.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pressure_pa: f64Pressure, Pa.
geopotential_height_m: f64Geopotential height above sea level as recorded, geopotential m.
height_msl_m: f64Geometric height above sea level, m (WMO-No. 8 eqs. 12.15 and 12.16 at the first row’s latitude).
temperature_k: f64Temperature, K.
relative_humidity: f64Relative humidity over liquid water as recorded, a fraction; it can exceed 1 in cloud.
wind_speed_m_s: f64Wind speed, m/s.
wind_direction_from_rad: f64Direction the wind blows from, clockwise from true north, rad, in [0, 2π).