#[non_exhaustive]pub enum FindError {
NotFound {
wanted: String,
},
Ambiguous {
wanted: String,
matches: u32,
candidates: Vec<String>,
},
Hybrid {
motor: String,
},
NoFile {
motor: String,
why: Option<String>,
},
ThrustCurve(ThrustCurveError),
}Expand description
Why no motor was found.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
No motor has the name as its designation or its common name.
Ambiguous
Several solid motors answer the name.
Fields
Hybrid
The one motor that answers is a hybrid.
NoFile
The motor has no RASP or RockSim file that hpr_motor reads.
Fields
ThrustCurve(ThrustCurveError)
A request or answer was refused, or the fetch failed.
Implementations